@@ -3,11 +3,13 @@ import os
 import sys
 
 __package__ = "meld"
-__version__ = "3.16.4"
+__version__ = "3.18.0"
 
 DATADIR = "/usr/local/share/meld"
 LOCALEDIR = "/usr/local/share/locale"
 UNINSTALLED = False
+UNINSTALLED_SCHEMA = False
+PYTHON_REQUIREMENT_TUPLE = (3, 3)
 
 # Installed from main script
 _ = lambda x: x
@@ -15,12 +17,13 @@ ngettext = lambda x, *args: x
 
 
 def frozen():
-    global DATADIR, LOCALEDIR
+    global DATADIR, LOCALEDIR, UNINSTALLED_SCHEMA
 
     melddir = os.path.dirname(sys.executable)
 
     DATADIR = os.path.join(melddir, "share", "meld")
     LOCALEDIR = os.path.join(melddir, "share", "mo")
+    UNINSTALLED_SCHEMA = True
 
     # This first bit should be unnecessary, but some things (GTK icon theme
     # location, GSettings schema location) don't fall back correctly.
@@ -30,13 +33,14 @@ def frozen():
 
 
 def uninstalled():
-    global DATADIR, LOCALEDIR, UNINSTALLED
+    global DATADIR, LOCALEDIR, UNINSTALLED, UNINSTALLED_SCHEMA
     melddir = os.path.abspath(os.path.join(
         os.path.dirname(os.path.realpath(__file__)), ".."))
 
     DATADIR = os.path.join(melddir, "data")
     LOCALEDIR = os.path.join(melddir, "build", "mo")
     UNINSTALLED = True
+    UNINSTALLED_SCHEMA = True
 
     # This first bit should be unnecessary, but some things (GTK icon theme
     # location, GSettings schema location) don't fall back correctly.
